@@ -46,26 +46,7 @@ temp
 
 
 ###################################################
-### code chunk number 6: figure1
-###################################################
-# Read the shapefile
-shp <- read.shape("Luck_Ash_streams")
-# Plot streams in the Luckiamute watershed classified by stream type
-print(spplot(shp, zcol="Per_Int", col.regions=c("red", "blue")))
-
-
-
-###################################################
-### code chunk number 7: figure2
-###################################################
-# Plot streams in the Luckiamute watershed classified by Strahler stream order
-# category
-print(spplot(shp, zcol="Strah_Cat", col.regions=c("red", "green", "blue")))
-
-
-
-###################################################
-### code chunk number 8: Equalsites
+### code chunk number 6: Equalsites
 ###################################################
 # Call the set.seed function so that the survey designs can be replicate
 set.seed(19742003)
@@ -73,7 +54,7 @@ set.seed(19742003)
 
 
 ###################################################
-### code chunk number 9: Equalsites
+### code chunk number 7: Equalsites
 ###################################################
 # Create the design list
 Equaldsgn <- list(None=list(panel=c(PanelOne=50), seltype="Equal"))
@@ -81,7 +62,7 @@ Equaldsgn <- list(None=list(panel=c(PanelOne=50), seltype="Equal"))
 
 
 ###################################################
-### code chunk number 10: Equalsites
+### code chunk number 8: Equalsites
 ###################################################
 # Select the sample
 Equalsites <- grts(design=Equaldsgn,
@@ -95,7 +76,7 @@ Equalsites <- grts(design=Equaldsgn,
 
 
 ###################################################
-### code chunk number 11: Equalsites
+### code chunk number 9: Equalsites
 ###################################################
 # Print the initial six lines of the survey design
 head(Equalsites@data)
@@ -103,15 +84,15 @@ head(Equalsites@data)
 
 
 ###################################################
-### code chunk number 12: Equalsites
+### code chunk number 10: Equalsites
 ###################################################
 # Print the survey design summary
-dsgnsum(Equalsites)
+summary(Equalsites)
 
 
 
 ###################################################
-### code chunk number 13: Stratsites
+### code chunk number 11: Stratsites
 ###################################################
 # Create the design list
 Stratdsgn <- list(Perennial=list(panel=c(PanelOne=50),
@@ -124,7 +105,7 @@ Stratdsgn <- list(Perennial=list(panel=c(PanelOne=50),
 
 
 ###################################################
-### code chunk number 14: Stratsites
+### code chunk number 12: Stratsites
 ###################################################
 # Select the sample
 Stratsites <- grts(design=Stratdsgn,
@@ -139,7 +120,7 @@ Stratsites <- grts(design=Stratdsgn,
 
 
 ###################################################
-### code chunk number 15: Stratsites
+### code chunk number 13: Stratsites
 ###################################################
 # Print the initial six lines of the survey design
 head(Stratsites@data)
@@ -147,15 +128,23 @@ head(Stratsites@data)
 
 
 ###################################################
-### code chunk number 16: Stratsites
+### code chunk number 14: Stratsites
 ###################################################
 # Print the survey design summary
-dsgnsum(Stratsites)
+summary(Stratsites)
 
 
 
 ###################################################
-### code chunk number 17: Unequalsites
+### code chunk number 15: Unequalsites
+###################################################
+# Read the shapefile
+shp <- read.shape("Luck_Ash_streams")
+
+
+
+###################################################
+### code chunk number 16: Unequalsites
 ###################################################
 # Create the design list
 Unequaldsgn <- list(Perennial=list(panel=c(PanelOne=75),
@@ -170,7 +159,7 @@ Unequaldsgn <- list(Perennial=list(panel=c(PanelOne=75),
 
 
 ###################################################
-### code chunk number 18: Unequalsites
+### code chunk number 17: Unequalsites
 ###################################################
 # Select the sample
 Unequalsites <- grts(design=Unequaldsgn,
@@ -186,7 +175,7 @@ Unequalsites <- grts(design=Unequaldsgn,
 
 
 ###################################################
-### code chunk number 19: Unequalsites
+### code chunk number 18: Unequalsites
 ###################################################
 # Print the initial six lines of the survey design
 head(Unequalsites@data)
@@ -194,15 +183,15 @@ head(Unequalsites@data)
 
 
 ###################################################
-### code chunk number 20: Unequalsites
+### code chunk number 19: Unequalsites
 ###################################################
 # Print the survey design summary
-dsgnsum(Unequalsites)
+summary(Unequalsites)
 
 
 
 ###################################################
-### code chunk number 21: Panelsites
+### code chunk number 20: Panelsites
 ###################################################
 # Create the design list
 Paneldsgn <- list(Perennial=list(panel=c(Annual=16, Year1=17, Year2=17),
@@ -216,7 +205,7 @@ Paneldsgn <- list(Perennial=list(panel=c(Annual=16, Year1=17, Year2=17),
 
 
 ###################################################
-### code chunk number 22: Panelsites
+### code chunk number 21: Panelsites
 ###################################################
 # Select the sample
 Panelsites <- grts(design=Paneldsgn,
@@ -232,7 +221,7 @@ Panelsites <- grts(design=Paneldsgn,
 
 
 ###################################################
-### code chunk number 23: Panelsites
+### code chunk number 22: Panelsites
 ###################################################
 # Print the initial six lines of the survey design
 head(Panelsites@data)
@@ -240,10 +229,10 @@ head(Panelsites@data)
 
 
 ###################################################
-### code chunk number 24: Panelsites
+### code chunk number 23: Panelsites
 ###################################################
 # Print the survey design summary
-dsgnsum(Panelsites)
+summary(Panelsites)
 
 
 
