@@ -10,6 +10,8 @@
 **  Programmers: Christian Platt, Tom Kincaid
 **  Created:     September 7, 2004
 **  Revised:     November 9, 2007
+**  Revised:     February 23, 2015
+**  Revised:     May 5, 2015
 ******************************************************************************/
 
 #include <stdio.h>
@@ -1537,14 +1539,14 @@ SEXP pointInPolygonFile( SEXP fileNamePrefix, SEXP xcsVec, SEXP ycsVec,
                                 /* to the array of ID numbers */
   int dsgSize = length( dsgnmdIDVec ); /* number of IDs in the dsgnmdID array */
   FILE * newShp = NULL;   /* pointer to the temporary .shp file */
-  char * shpFileName = NULL;  /* stores full shape file name */
+  char * restrict shpFileName = NULL;  /* stores full shape file name */
   int singleFile = FALSE;
 
   /* see if a specific file was sent */
   if ( fileNamePrefix != R_NilValue ) {
 
     /* create the full .shp file name */
-    if ((shpFileName = (char *)malloc(strlen(CHAR(STRING_ELT(fileNamePrefix,0)))
+    if ((shpFileName = (char * restrict)malloc(strlen(CHAR(STRING_ELT(fileNamePrefix,0)))
                                               + strlen(".shp") + 1)) == NULL ){
       Rprintf( "Error: Allocating memory in C function pointInPolygonFile.\n" );
       PROTECT( results = allocVector( VECSXP, 1 ) );
