@@ -3,6 +3,8 @@
 **  Programmer:  Tom Kincaid
 **  Date:        May 19, 2010
 **  Revised:     November 3, 2011
+**  Revised:     February 23, 2015
+**  Revised:     May 5, 2015
 **  Description:
 **    For each value in the set of shapefile record IDs, select a sample point
 **    from the shapefile record 
@@ -59,7 +61,7 @@ SEXP pickAreaSamplePoints(SEXP fileNamePrefix, SEXP shpIDsVec, SEXP recordIDsVec
   int i, j, k, l;             /* loop counters */
   FILE * fptr = NULL;         /* pointer to the shapefile */
   FILE * newShp = NULL;       /* pointer to the temporary .shp file */
-  char * shpFileName = NULL;  /* stores full shape file name */
+  char * restrict shpFileName = NULL;  /* stores full shape file name */
   int singleFile = FALSE;
   Shape shape;           /* used to store shapefile info and data */
   Point * part = NULL;   /* stores points in a part */
@@ -106,7 +108,7 @@ SEXP pickAreaSamplePoints(SEXP fileNamePrefix, SEXP shpIDsVec, SEXP recordIDsVec
   if(fileNamePrefix != R_NilValue) {
 
     /* create the full .shp file name */
-    if((shpFileName = (char *)malloc(strlen(CHAR(STRING_ELT(fileNamePrefix,0)))
+    if((shpFileName = (char * restrict)malloc(strlen(CHAR(STRING_ELT(fileNamePrefix,0)))
                                               + strlen(".shp") + 1)) == NULL){
       Rprintf("Error: Allocating memory in C function pickAreaSamplePoints.\n");
       PROTECT(results = allocVector(VECSXP, 1));
